summaryrefslogtreecommitdiff
path: root/pkg/cli/query.go
diff options
context:
space:
mode:
Diffstat (limited to 'pkg/cli/query.go')
-rw-r--r--pkg/cli/query.go6
1 files changed, 3 insertions, 3 deletions
diff --git a/pkg/cli/query.go b/pkg/cli/query.go
index ed9e913..d9aa9a2 100644
--- a/pkg/cli/query.go
+++ b/pkg/cli/query.go
@@ -41,7 +41,7 @@ func (e errInterrupted) Error() string {
// TUI implementation for when stdin is a terminal
type terminalTUI struct {
- i *Interface
+ i *Implementation
}
func (t terminalTUI) ReadLine(prompt string) (string, error) {
@@ -78,7 +78,7 @@ type Choice struct {
Shortcut byte
//The display string that describes this choice.
Text string
//The string to return from Interface.Query().
Return string
}
@@ -228,7 +228,7 @@ func (b *buffer) getNextInput() []byte {
// TUI implementation for when stdin is a pipe
type pipeTUI struct {
- i *Interface
+ i *Implementation
}
func (t *pipeTUI) ReadLine(prompt string) (string, error) {
@@ -78,7 +78,7 @@ type Choice struct {
//The display string that describes this choice.
Text string
- //The string to return from Interface.Query().
+ //The string to return from Implementation.Query().
Return string
}